Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1862)

Unified Diff: scripts/image_signing/unpack_firmwarefd.sh

Issue 3388002: Change tool "fmap_decode" to "mosys" (Closed) Base URL: ssh://git@gitrw.chromium.org:9222/vboot_reference.git
Patch Set: Created 10 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « scripts/image_signing/resign_firmwarefd.sh ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: scripts/image_signing/unpack_firmwarefd.sh
diff --git a/scripts/image_signing/unpack_firmwarefd.sh b/scripts/image_signing/unpack_firmwarefd.sh
index f16f6b49bff66db5dfba9a02f3a3ecce13849ae1..bf8df6ab2027dcc885d70b35adfff8b2b5cd82e4 100755
--- a/scripts/image_signing/unpack_firmwarefd.sh
+++ b/scripts/image_signing/unpack_firmwarefd.sh
@@ -7,7 +7,7 @@
# Script that unpacks a firmware image (in .fd format) into its component
# pieces. Only outputs firmware A and B data, vblocks and the GBB.
# The fmap_decode tool must be in the system path.
# Abort on error
set -e
@@ -20,14 +20,14 @@ if [ $# -ne 1 ] ; then
fi
# Make sure the tools we need are available.
-type -P fmap_decode &>/dev/null || \
- { echo "fmap_decode tool not found."; exit 1; }
+type -P mosys &>/dev/null || \
+ { echo "mosys tool not found."; exit 1; }
src_fd=$1
# Grab GBB Area offset and size
match_str="GBB Area"
-line=$(fmap_decode $1 | grep "$match_str")
+line=$(mosys -f -k eeprom map $1 | grep "$match_str")
offset="$(echo $line | sed -e 's/.*area_offset=\"\([a-f0-9x]*\)\".*/\1/')"
let gbb_offset="$offset"
size="$(echo $line | sed -e 's/.*area_size=\"\([a-f0-9x]*\)\".*/\1/')"
@@ -37,7 +37,7 @@ let gbb_size="$size"
for i in "A" "B"
do
match_str="$i Key"
- line=$(fmap_decode $1 | grep "$match_str")
+ line=$(mosys -f -k eeprom map $1 | grep "$match_str")
offset="$(echo $line | sed -e 's/.*area_offset=\"\([a-f0-9x]*\)\".*/\1/')"
eval let \
fw${i}_vblock_offset="$offset"
@@ -46,7 +46,7 @@ do
fw${i}_vblock_size="$size"
match_str="$i Data"
- line=$(fmap_decode $1 | grep "$match_str")
+ line=$(mosys -f -k eeprom map $1 | grep "$match_str")
offset="$(echo $line | sed -e 's/.*area_offset=\"\([a-f0-9x]*\)\".*/\1/')"
eval let \
fw${i}_offset="$offset"
@@ -7,7 +7,7 @@
# Script that unpacks a firmware image (in .fd format) into its component
# pieces. Only outputs firmware A and B data, vblocks and the GBB.
-# The fmap_decode tool must be in the system path.
+# The mosys tool must be in the system path.
# Abort on error
set -e
« no previous file with comments | « scripts/image_signing/resign_firmwarefd.sh ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698